collective.recipe.vimproject
============================

:Author:    $Author: seletz $
:Date:      $Date: 2008-02-19 15:12:00 +0100 (Di, 19 Feb 2008) $
:Revision:  $Revision: 59017 $

Abstract
--------

This is a recipe to create a VIM project file. This is good for development,
and if you use VIM_ with the Project_ plugin.

This recipe makes use of the mkvimproject_ egg.

Options
-------

All options are **optional**.

patterns
  a list of patterns to be included in the project file

create_tagfile
  If this key exists, the recipe wil also use **ctags** to create a tag
  file of the buildout directory

tags
  This list will be added to the **in.vim** script to set the tag files.
  Here you can add special directories (like buildout egg caches)

in_vim_additional
  additional statements to add verbatim to the **in.vim** script.

Usage
-----

Just add a buildout section like this::

    [buildout]
    parts=vpj

    [vpj]
    recipe = collective.recipe.vimproject
    patterns=.py .zcml .pt .cfg .xml .txt .rst
    create_tagfile=yes
    in_vim_additional=
      set hlsearch
    tags=/opt/inquant/buildout/eggs/tags


.. _VIM: http://vim.org
.. _Project: http://www.vim.org/scripts/script.php?script_id=69
.. _mkvimproject: http://pypi.python.org/pypi/mkvimproject/


::

 vim: set ft=rst tw=75 nocin nosi ai sw=4 ts=4 expandtab:
